/*
 * NAME:
 *	hname - get local hostname
 *
 * SYNOPSIS:
 *	char *Hostname(int "f")
 *
 * DESCRIPTION:
 *	Determines local hostname (on first call only), and if "f" is
 *	true, returns it fully qualified, otherwise truncated at the
 *	first ``.''
 *	
 * AUTHOR:
 *	Simon J. Gerraty <sjg@quick.com.au>
 */
/*
 *	@(#)Copyright (c) 1996 Simon J. Gerraty.
 *	
 *	This is free software.	It comes with NO WARRANTY.
 *	Permission to use, modify and distribute this source code 
 *	is granted subject to the following conditions.
 *	1/ that the above copyright notice and this notice 
 *	are preserved in all copies and that due credit be given 
 *	to the author.	
 *	2/ that any changes to this code are clearly commented 
 *	as such so that the author does not get blamed for bugs 
 *	other than his own.
 *	
 *	Please send copies of changes and bug-fixes to:
 *	sjg@quick.com.au
 */
#ifndef lint
static char RCSid[] = "$Id: hname.c,v 1.1 1998/07/14 07:20:49 sjg Exp $";
#endif
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#include <sys/param.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>

const char *
Hostname(f)
	int f;
{
	static const char *fqdn = 0;
	static const char *hn = 0;
	char *cp;
	
	if (fqdn == 0) {
		struct hostent *hp;
		char hostbuf[2 * MAXHOSTNAMELEN + 1];

		(void) gethostname(hostbuf, sizeof(hostbuf));
		if (hp = gethostbyname(hostbuf)) {
			fqdn = strdup(hp->h_name);
		} else {
			fqdn = strdup(hostbuf);
		}
		if (cp = strchr(fqdn, '.')) {
			*cp = '\0';
			hn = strdup(fqdn);
			*cp = '.';
		} else {
			hn = fqdn;
		}
	}
	return (f) ? fqdn : hn;
}
